@@ -1,18 +1,19 @@
 package App::Action::TicketUpdate;
 
-# $Id: TicketUpdate.pm,v 1.4 2004/10/11 22:22:26 cwinters Exp $
+# $Id: TicketUpdate.pm,v 1.5 2004/10/13 20:05:09 cwinters Exp $
 
 use strict;
 use base qw( Workflow::Action );
 use Log::Log4perl qw( get_logger );
 use Workflow::History;
 
-$App::Action::TicketUpdate::VERSION  = sprintf("%d.%02d", q$Revision: 1.4 $ =~ /(\d+)\.(\d+)/);
+$App::Action::TicketUpdate::VERSION  = sprintf("%d.%02d", q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/);
 
 sub execute {
     my ( $self, $wf ) = @_;
     my $log = get_logger();
-    $log->debug( "Action '", $self->name, "' with class '", ref( $self ), "' executing..." );
+    $log->debug( "Action '", $self->name, "' with class ",
+                 "'", ref( $self ), "' executing..." );
     my $ticket = $wf->context->param( 'ticket' );
     $ticket->status( $wf->state );
     $ticket->update;
