@@ -1,25 +1,36 @@
 package Workflow::Persister::DBI::SequenceId;
 
-# $Id: SequenceId.pm,v 1.3 2004/03/08 04:56:09 cwinters Exp $
+# $Id: SequenceId.pm,v 1.4 2005/11/30 03:14:50 cwinters Exp $
 
 use strict;
 use base qw( Class::Accessor );
+use DBI;
+use Log::Log4perl       qw( get_logger );
+use Workflow::Exception qw( persist_error );
 
-$Workflow::Persister::DBI::SequenceId::VERSION  = sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/);
+$Workflow::Persister::DBI::SequenceId::VERSION  = sprintf("%d.%02d", q$Revision: 1.4 $ =~ /(\d+)\.(\d+)/);
 
 my @FIELDS = qw( sequence_name sequence_select );
 __PACKAGE__->mk_accessors( @FIELDS );
 
+my ( $log );
+
 sub pre_fetch_id {
     my ( $self, $dbh ) = @_;
+    $log ||= get_logger();
     my $full_select = sprintf( $self->sequence_select, $self->sequence_name );
-    my ( $sth );
+    $log->is_debug &&
+        $log->debug( "SQL to fetch sequence: $full_select" );
+    my ( $row );
     eval {
-        $sth = $dbh->prepare( $full_select );
+        my $sth = $dbh->prepare( $full_select );
         $sth->execute;
+        $row = $sth->fetchrow_arrayref;
+        $sth->finish;
     };
-    my $row = $sth->fetchrow_arrayref;
-    $sth->finish;
+    if ( $@ ) {
+        persist_error "Failed to retrieve sequence: $@";
+    }
     return $row->[0];
 }
 
