@@ -1,6 +1,6 @@
 package TestUtil;
 
-# $Id: TestUtil.pm,v 1.5 2004/10/17 15:22:26 cwinters Exp $
+# $Id: TestUtil.pm,v 1.6 2005/11/30 03:25:17 cwinters Exp $
 
 use strict;
 use DateTime;
@@ -44,7 +44,7 @@ sub check_workflow_history {
     my ( $class, $tracker, $values ) = @_;
     $class->check_tracker(
         $tracker, 'create workflow history',
-        qr/^INSERT INTO workflow_history \( workflow_id, action, description, state, user, history_date, workflow_hist_id \)/,
+        qr/^INSERT INTO workflow_history \( workflow_id, action, description, state, workflow_user, history_date, workflow_hist_id \)/,
         [ 'workflow ID', 'action', 'description',
           'state', 'user', 'current date',
           'random ID of correct length' ],
